# esp-idf-size

The ```esp-idf-size``` package is part of the [ESP-IDF](https://github.com/espressif/esp-idf) SDK for Espressif products and is automatically installed.

It is responsible for analyzing firmware binary size of ESP-IDF projects.
